Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Config ¶
type Config struct {
// Addr of the JSON-RPC server
// should be a valid URL with a scheme of either http, https, ws or wss
Addr string `json:"addr"`
// HTTP is a configuration for HTTP client MUST be provided if addr scheme is http or https
HTTP *jsonrpchttp.Config `json:"http"`
// WS is a configuration for WebSocket client MUST be provided if addr scheme is ws or wss
WS *jsonrpcws.Config `json:"ws"`
}
Config is a configuration for a JSON-RPC client
func (*Config) SetDefault ¶
SetDefault sets the default values for the configuration
Click to show internal directories.
Click to hide internal directories.