httptestutils

package
v0.11.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 3, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

Package httptestutils is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewGockRequest

func NewGockRequest() *gock.Request

NewGockRequest creates a new gock request

Types

type MockSender

type MockSender struct {
	// contains filtered or unexported fields
}

MockSender is a mock of Sender interface.

func NewMockSender

func NewMockSender(ctrl *gomock.Controller) *MockSender

NewMockSender creates a new mock instance.

func (*MockSender) Do

func (m *MockSender) Do(arg0 *http.Request) (*http.Response, error)

Do mocks base method.

func (*MockSender) EXPECT

func (m *MockSender) EXPECT() *MockSenderMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

type MockSenderMockRecorder

type MockSenderMockRecorder struct {
	// contains filtered or unexported fields
}

MockSenderMockRecorder is the mock recorder for MockSender.

func (*MockSenderMockRecorder) Do

func (mr *MockSenderMockRecorder) Do(arg0 interface{}) *gomock.Call

Do indicates an expected call of Do.

func (*MockSenderMockRecorder) DoGock

func (mr *MockSenderMockRecorder) DoGock(req *gock.Request) *gomock.Call

DoGock declares a call to Do with a mocked gock request and responder

Jump to