file

package
v0.6.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 9, 2025 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Store

type Store struct {
	// contains filtered or unexported fields
}

func New

func New(dataDir string) *Store

func (*Store) Copy

func (f *Store) Copy(_ context.Context, srcKey, dstKey string) error

func (*Store) Delete

func (f *Store) Delete(_ context.Context, key string) error

func (*Store) Load

func (f *Store) Load(_ context.Context, key string) (io.ReadCloser, *store.Headers, error)

Load loads the data from the file It is the responsibility of the caller to close the returned reader

func (*Store) Store

func (f *Store) Store(_ context.Context, key string, reader io.Reader, _ *store.Headers) error

Store stores the data in the file

Jump to