Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CopySlice ¶
func CopySlice[T any](v ...*T) []*T
CopySlice returns a slice of copies of the given pointers
func PtrSlice ¶
func PtrSlice[T any](v ...T) *[]*T
PtrSlice returns a pointer to a slice of pointers to all of the provided values.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.